@@ -1,14 +1,13 @@
-var _ = require('underscore');
 var OrthographicCameraAutogen = require('./OrthographicCamera.autogen');
 
-var OrthographicCameraModel = OrthographicCameraAutogen.OrthographicCameraModel.extend({
+class OrthographicCameraModel extends OrthographicCameraAutogen.OrthographicCameraModel {
     // push data from model to three object
-    syncToThreeObj: function() {
+    syncToThreeObj() {
         OrthographicCameraAutogen.OrthographicCameraModel.prototype.syncToThreeObj.apply(this, arguments);
         // Always update the projection matrix after setting the attributes:
         this.obj.updateProjectionMatrix();
     }
-});
+}
 
 module.exports = {
     OrthographicCameraModel: OrthographicCameraModel,
