@@ -1,23 +1,23 @@
 var DepthTextureBase = require('./DepthTexture.autogen');
 
-var DepthTextureModel = DepthTextureBase.DepthTextureModel.extend({
+class DepthTextureModel extends DepthTextureBase.DepthTextureModel {
 
-    createPropertiesArrays: function() {
+    createPropertiesArrays() {
         DepthTextureBase.DepthTextureModel.prototype.createPropertiesArrays.call(this);
 
         // three.js DepthTexture stores the width, and height props together in a dict called 'image'
         this.property_mappers['DepthTextureData'] = 'mapDepthTextureData';
-    },
+    }
 
 
-    mapDepthTextureDataModelToThree: function() {
+    mapDepthTextureDataModelToThree() {
         var width = this.get('width');
         var height = this.get('height');
         this.obj.image = { width: width, height: height };
         this.obj.needsUpdate = true;
-    },
+    }
 
-    mapDepthTextureDataThreeToModel: function() {
+    mapDepthTextureDataThreeToModel() {
         var imageRecord = this.obj.image;
 
         // this.image = { width: width, height: height };
@@ -26,9 +26,9 @@ var DepthTextureModel = DepthTextureBase.DepthTextureModel.extend({
 
         this.set('width', dataWidth);
         this.set('height', dataHeight);
-    },
+    }
 
-});
+}
 
 module.exports = {
     DepthTextureModel: DepthTextureModel,
